@@ -28,8 +28,14 @@ pub use k8s_openapi::Resource;
 pub use ext::ClusterRoleBindingExt;
 pub use ext::ClusterRoleExt;
 pub use ext::ConfigMapExt;
+pub use ext::ContainerExt;
+pub use ext::DaemonSetExt;
 pub use ext::DeploymentExt;
+pub use ext::EnvVarExt;
+pub use ext::LabelSelectorExt;
 pub use ext::NamespaceExt;
+pub use ext::PodSpecExt;
+pub use ext::PodTemplateSpecExt;
 pub use ext::PolicyRuleExt;
 pub use ext::ResourceExt;
 pub use ext::RoleBindingExt;
@@ -37,6 +43,7 @@ pub use ext::RoleExt;
 pub use ext::RoleRefExt;
 pub use ext::SecretExt;
 pub use ext::ServiceAccountExt;
+pub use ext::ServiceExt;
 pub use ext::SubjectExt;
 
 pub use kubectl::Kubectl;
